==> haskell-quickcheck-2.15.0.1-90.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 QuickCheck
version:              2.15.0.1
visibility:           public
id:                   QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
key:                  QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
license:              BSD-3-Clause
copyright:
    2000-2019 Koen Claessen, 2006-2008 Björn Bringert, 2009-2019 Nick Smallbone

maintainer:           Nick Smallbone <nick@smallbone.se>
author:               Koen Claessen <koen@chalmers.se>
homepage:             https://github.com/nick8325/quickcheck
synopsis:             Automatic testing of Haskell programs
description:
    QuickCheck is a library for random testing of program properties.
    The programmer provides a specification of the program, in the form of
    properties which functions should satisfy, and QuickCheck then tests that the
    properties hold in a large number of randomly generated cases.
    Specifications are expressed in Haskell, using combinators provided by
    QuickCheck. QuickCheck provides combinators to define properties, observe the
    distribution of test data, and define test data generators.

    Most of QuickCheck'\''s functionality is exported by the main "Test.QuickCheck"
    module. The main exception is the monadic property testing library in
    "Test.QuickCheck.Monadic".

    If you are new to QuickCheck, you can try looking at the following resources:

    * The <http://www.cse.chalmers.se/~rjmh/QuickCheck/manual.html official QuickCheck manual>.
    It'\''s a bit out-of-date in some details and doesn'\''t cover newer QuickCheck features,
    but is still full of good advice.
    * <https://begriffs.com/posts/2017-01-14-design-use-quickcheck.html>,
    a detailed tutorial written by a user of QuickCheck.

    The <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>
    companion package provides instances for types in Haskell Platform packages
    at the cost of additional dependencies.

category:             Testing
abi:                  c2ae196d4fc6897f647c70dd7450a6f8
exposed:              True
exposed-modules:
    Test.QuickCheck Test.QuickCheck.All Test.QuickCheck.Arbitrary
    Test.QuickCheck.Exception Test.QuickCheck.Features
    Test.QuickCheck.Function Test.QuickCheck.Gen
    Test.QuickCheck.Gen.Unsafe Test.QuickCheck.Modifiers
    Test.QuickCheck.Monadic Test.QuickCheck.Poly
    Test.QuickCheck.Property Test.QuickCheck.Random
    Test.QuickCheck.State Test.QuickCheck.Test Test.QuickCheck.Text

import-dirs:          /usr/lib/ghc-9.6.6/site-local/QuickCheck-2.15.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/QuickCheck-2.15.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/QuickCheck-2.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/loongarch64-linux-ghc-9.6.6/QuickCheck-2.15.0.1
hs-libraries:         HSQuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
depends:
    base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    random-1.2.1.3-6SxnlPLCqt06GlpnYLfwZm
    splitmix-0.1.3-9CESEz75Upa7nQgfltLRDI template-haskell-2.20.0.0
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-quickcheck/html/QuickCheck.haddock
haddock-html:         /usr/share/doc/haskell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-2.15.0.1-92-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 QuickCheck
version:              2.15.0.1
visibility:           public
id:                   QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS
key:                  QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS
license:              BSD-3-Clause
copyright:
    2000-2019 Koen Claessen, 2006-2008 Björn Bringert, 2009-2019 Nick Smallbone

maintainer:           Nick Smallbone <nick@smallbone.se>
author:               Koen Claessen <koen@chalmers.se>
homepage:             https://github.com/nick8325/quickcheck
synopsis:             Automatic testing of Haskell programs
description:
    QuickCheck is a library for random testing of program properties.
    The programmer provides a specification of the program, in the form of
    properties which functions should satisfy, and QuickCheck then tests that the
    properties hold in a large number of randomly generated cases.
    Specifications are expressed in Haskell, using combinators provided by
    QuickCheck. QuickCheck provides combinators to define properties, observe the
    distribution of test data, and define test data generators.

    Most of QuickCheck'\''s functionality is exported by the main "Test.QuickCheck"
    module. The main exception is the monadic property testing library in
    "Test.QuickCheck.Monadic".

    If you are new to QuickCheck, you can try looking at the following resources:

    * The <http://www.cse.chalmers.se/~rjmh/QuickCheck/manual.html official QuickCheck manual>.
    It'\''s a bit out-of-date in some details and doesn'\''t cover newer QuickCheck features,
    but is still full of good advice.
    * <https://begriffs.com/posts/2017-01-14-design-use-quickcheck.html>,
    a detailed tutorial written by a user of QuickCheck.

    The <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>
    companion package provides instances for types in Haskell Platform packages
    at the cost of additional dependencies.

category:             Testing
abi:                  d124ecae49120033bf02f5d6fc413bfe
exposed:              True
exposed-modules:
    Test.QuickCheck Test.QuickCheck.All Test.QuickCheck.Arbitrary
    Test.QuickCheck.Exception Test.QuickCheck.Features
    Test.QuickCheck.Function Test.QuickCheck.Gen
    Test.QuickCheck.Gen.Unsafe Test.QuickCheck.Modifiers
    Test.QuickCheck.Monadic Test.QuickCheck.Poly
    Test.QuickCheck.Property Test.QuickCheck.Random
    Test.QuickCheck.State Test.QuickCheck.Test Test.QuickCheck.Text

import-dirs:          /usr/lib/ghc-9.6.6/site-local/QuickCheck-2.15.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/QuickCheck-2.15.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/QuickCheck-2.15.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/loongarch64-linux-ghc-9.6.6/QuickCheck-2.15.0.1
hs-libraries:         HSQuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS
depends:
    base-4.18.2.1 containers-0.6.7 deepseq-1.4.8.1
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj
    splitmix-0.1.3-90QrqABg5SpKi5FtNwnDR8 template-haskell-2.20.0.0
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-quickcheck/html/QuickCheck.haddock
haddock-html:         /usr/share/doc/haskell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
